@@ -3,13 +3,7 @@ Created on 16/07/2013
 
 @author: mmpe
 '''
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from future import standard_library
 from wetb import gtsdf
-standard_library.install_aliases()
 
 
 import unittest
