@@ -3,14 +3,6 @@ Created on 12/09/2013
 
 @author: mmpe
 '''
-from __future__ import division
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import super
-from builtins import range
-from future import standard_library
-standard_library.install_aliases()
 
 import h5py
 import numpy as np
@@ -48,7 +40,7 @@ class Test_gsdf(unittest.TestCase):
         fn = tmp_path + "test_compress2stat.hdf5"
         gtsdf.save(fn, data, time=time, **info)
         del info['dtype']
-        gtsdf.save(tmp_path + "test_compress2stat2.hdf5", data, time=time, dtype=np.float, **info)
+        gtsdf.save(tmp_path + "test_compress2stat2.hdf5", data, time=time, dtype=float, **info)
         gtsdf.compress2statistics(fn)
         self.assertLess(os.path.getsize(fn) * 50, os.path.getsize(tfp + 'test.hdf5'))
 
