@@ -3,12 +3,6 @@ Created on 03/12/2015
 
 @author: mmpe
 '''
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 import unittest
 import numpy as np
 import datetime
