@@ -3,12 +3,6 @@ Created on 10/01/2014
 
 @author: MMPE
 '''
-from __future__ import division
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
 import numpy as np
 from pandas import read_csv
