@@ -1,21 +1,13 @@
 '''
 Created on 20/01/2014
 
-@author: MMPE
-
 See documentation of HTCFile below
 
 '''
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-from __future__ import absolute_import
-from builtins import str
-from future import standard_library
 from wetb.utils.process_exec import pexec
 from wetb.hawc2.hawc2_pbs_file import HAWC2PBSFile
 import jinja2
-standard_library.install_aliases()
+from wetb.utils.cluster_tools.os_path import fixcase, abspath, pjoin
 from collections import OrderedDict
 from wetb.hawc2.htc_contents import HTCContents, HTCSection, HTCLine
 from wetb.hawc2.htc_extensions import HTCDefaults, HTCExtensions
@@ -79,7 +71,6 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
     level = 0
     modelpath = "../"
     initial_comments = None
-    _contents = None
 
     def __init__(self, filename=None, modelpath=None, jinja_tags={}):
         """
@@ -90,9 +81,12 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         modelpath : str
             Model path relative to htc file
         """
-
         if filename is not None:
-            with self.open(str(filename)):
+            try:
+                filename = fixcase(abspath(filename))
+                with self.open(str(filename)):
+                    pass
+            except Exception:
                 pass
 
             self.filename = filename
@@ -103,8 +97,10 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         if filename and self.modelpath != "unknown" and not os.path.isabs(self.modelpath):
             drive, p = os.path.splitdrive(os.path.join(os.path.dirname(str(self.filename)), self.modelpath))
             self.modelpath = os.path.join(drive, os.path.splitdrive(os.path.realpath(p))[1]).replace("\\", "/")
+        if self.modelpath != 'unknown' and self.modelpath[-1] != '/':
+            self.modelpath += "/"
 
-            #assert 'simulation' in self.contents, "%s could not be loaded. 'simulation' section missing" % filename
+        self.load()
 
     def auto_detect_modelpath(self):
         if self.filename is None:
@@ -113,32 +109,30 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         #print (["../"*i for i in range(3)])
         import numpy as np
         input_files = HTCFile(self.filename, 'unknown').input_files()
-        if len(input_files) == 1:
+        if len(input_files) == 1:  # only input file is the htc file
             return "../"
         rel_input_files = [f for f in input_files if not os.path.isabs(f)]
 
         def isfile_case_insensitive(f):
             try:
-                self.unix_path(f)
-                return True
+                f = fixcase(f)  # raises exception if not existing
+                return os.path.isfile(f)
             except IOError:
                 return False
         found = ([np.sum([isfile_case_insensitive(os.path.join(os.path.dirname(self.filename), "../" * i, f))
                           for f in rel_input_files]) for i in range(4)])
-        # for f in self.input_files():
-        #     print(os.path.isfile(os.path.join(os.path.dirname(self.filename), "../", f)), f)
+
         if max(found) > 0:
             relpath = "../" * np.argmax(found)
-            return os.path.abspath(os.path.join(os.path.dirname(self.filename), relpath))
+            return abspath(pjoin(os.path.dirname(self.filename), relpath))
         else:
             raise ValueError(
                 "Modelpath cannot be autodetected for '%s'.\nInput files not found near htc file" % self.filename)
 
-    def _load(self):
-        self.reset()
+    def load(self):
+        self.contents = OrderedDict()
         self.initial_comments = []
         self.htc_inputfiles = []
-        self.contents = OrderedDict()
         if self.filename is None:
             lines = self.empty_htc.split("\n")
         else:
@@ -158,21 +152,8 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
                     break
                 self._add_contents(line)
 
-    def reset(self):
-        self._contents = None
-
-    @property
-    def contents(self):
-        if self._contents is None:
-            self._load()
-        return self._contents
-
-    @contents.setter
-    def contents(self, value):
-        self._contents = value
-
     def readfilelines(self, filename):
-        with self.open(self.unix_path(filename), encoding='cp1252') as fid:
+        with self.open(self.unix_path(os.path.abspath(filename.replace('\\', '/'))), encoding='cp1252') as fid:
             txt = fid.read()
         if txt[:10].encode().startswith(b'\xc3\xaf\xc2\xbb\xc2\xbf'):
             txt = txt[3:]
@@ -182,7 +163,8 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         return txt.replace("\r", "").split("\n")
 
     def readlines(self, filename):
-        self.htc_inputfiles.append(filename)
+        if filename != self.filename:  # self.filename may be changed by set_name/save. Added it when needed instead
+            self.htc_inputfiles.append(filename)
         htc_lines = []
         lines = self.readfilelines(filename)
         for l in lines:
@@ -191,7 +173,8 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
 
                 if self.modelpath == 'unknown':
                     p = os.path.dirname(self.filename)
-                    lu = [os.path.isfile(os.path.join(p, "../" * i, filename)) for i in range(4)].index(True)
+                    lu = [os.path.isfile(os.path.abspath(os.path.join(p, "../" * i, filename.replace("\\", "/"))))
+                          for i in range(4)].index(True)
                     filename = os.path.join(p, "../" * lu, filename)
                 else:
                     filename = os.path.join(self.modelpath, filename)
@@ -237,11 +220,12 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
                 self.simulation.animation = os.path.join(fmt_folder(
                     'animation', subfolder), "%s.dat" % name).replace("\\", "/")
             if 'visualization' in self.simulation:
-                self.simulation.visualization = os.path.join(fmt_folder(
-                    'visualization', subfolder), "%s.hdf5" % name).replace("\\", "/")
+                f = os.path.join(fmt_folder('visualization', subfolder), "%s.hdf5" % name).replace("\\", "/")
+                self.simulation.visualization[0] = f
         elif 'test_structure' in self and 'logfile' in self.test_structure:  # hawc2aero
             self.test_structure.logfile = os.path.join(fmt_folder('log', subfolder), "%s.log" % name).replace("\\", "/")
-        self.output.filename = os.path.join(fmt_folder('res', subfolder), "%s" % name).replace("\\", "/")
+        if 'output' in self:
+            self.output.filename = os.path.join(fmt_folder('res', subfolder), "%s" % name).replace("\\", "/")
 
     def set_time(self, start=None, stop=None, step=None):
         self.contents  # load if not loaded
@@ -282,9 +266,9 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
     def input_files(self):
         self.contents  # load if not loaded
         if self.modelpath == "unknown":
-            files = [str(f).replace("\\", "/") for f in self.htc_inputfiles]
+            files = [str(f).replace("\\", "/") for f in [self.filename] + self.htc_inputfiles]
         else:
-            files = [os.path.abspath(str(f)).replace("\\", "/") for f in self.htc_inputfiles]
+            files = [os.path.abspath(str(f)).replace("\\", "/") for f in [self.filename] + self.htc_inputfiles]
         if 'new_htc_structure' in self:
             for mb in [self.new_htc_structure[mb]
                        for mb in self.new_htc_structure.keys() if mb.startswith('main_body')]:
@@ -333,7 +317,18 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         except Exception:
             pass
 
-        return [f for f in set(files) if f]
+        def fix_path_case(f):
+            if os.path.isabs(f):
+                return self.unix_path(f)
+            elif self.modelpath != "unknown":
+                try:
+                    return "./" + os.path.relpath(self.unix_path(os.path.join(self.modelpath, f)),
+                                                  self.modelpath).replace("\\", "/")
+                except IOError:
+                    return f
+            else:
+                return f
+        return [fix_path_case(f) for f in set(files) if f]
 
     def output_files(self):
         self.contents  # load if not loaded
@@ -411,27 +406,36 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
 
         self.save()
         htcfile = os.path.relpath(self.filename, self.modelpath)
-        assert os.path.isfile(exe), exe
+        assert any([os.path.isfile(os.path.join(f, exe)) for f in [''] + os.environ['PATH'].split(";")]), exe
         return pexec([exe, htcfile], self.modelpath)
 
     def simulate(self, exe, skip_if_up_to_date=False):
         errorcode, stdout, stderr, cmd = self._simulate(exe, skip_if_up_to_date)
-        if 'simulation' in self.keys() and "logfile" in self.simulation:
+        if ('simulation' in self.keys() and "logfile" in self.simulation and
+                os.path.isfile(os.path.join(self.modelpath, self.simulation.logfile[0]))):
             with self.open(os.path.join(self.modelpath, self.simulation.logfile[0])) as fid:
                 log = fid.read()
         else:
-            log = stderr
+            log = "%s\n%s" % (str(stdout), str(stderr))
 
         if errorcode or 'Elapsed time' not in log:
             log_lines = log.split("\n")
             error_lines = [i for i, l in enumerate(log_lines) if 'error' in l.lower()]
             if error_lines:
-                i = error_lines[0]
-                error_log = "\n".join(log_lines[i - 3:i + 3])
+                import numpy as np
+                line_i = np.r_[np.array([error_lines + i for i in np.arange(-3, 4)]).flatten(),
+                               np.arange(-5, 0) + len(log_lines)]
+                line_i = sorted(np.unique(np.maximum(np.minimum(line_i, len(log_lines) - 1), 0)))
+
+                lines = ["%04d %s" % (i, log_lines[i]) for i in line_i]
+                for jump in np.where(np.diff(line_i) > 1)[0]:
+                    lines.insert(jump, "...")
+
+                error_log = "\n".join(lines)
             else:
                 error_log = log
-            raise Exception("\nstdout:\n%s\n--------------\nstderr:\n%s\n--------------\nlog:\n%s\n--------------\ncmd:\n%s" %
-                            (str(stdout), str(stderr), error_log, cmd))
+            raise Exception("\nError code: %s\nstdout:\n%s\n--------------\nstderr:\n%s\n--------------\nlog:\n%s\n--------------\ncmd:\n%s" %
+                            (errorcode, str(stdout), str(stderr), error_log, cmd))
         return str(stdout) + str(stderr), log
 
     def simulate_hawc2stab2(self, exe):
@@ -461,8 +465,9 @@ class HTCFile(HTCContents, HTCDefaults, HTCExtensions):
         for f in rest[1:].split("/"):
             f_lst = [f_ for f_ in os.listdir(ufn) if f_.lower() == f.lower()]
             if len(f_lst) > 1:
+                # use the case sensitive match
                 f_lst = [f_ for f_ in f_lst if f_ == f]
-            elif len(f_lst) == 0:
+            if len(f_lst) == 0:
                 raise IOError("'%s' not found in '%s'" % (f, ufn))
             else:  # one match found
                 ufn = os.path.join(ufn, f_lst[0])
@@ -527,10 +532,11 @@ class SSH_HTCFile(HTCFile):
 
 if "__main__" == __name__:
     f = HTCFile(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT_power_curve.htc", "../")
-    f.save(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT_power_curve.htc")
-
-    f = HTCFile(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT.htc", "../")
-    f.set_time = 0, 1, .1
-    print(f.simulate(r"C:\mmpe\HAWC2\bin\HAWC2_12.8\hawc2mb.exe"))
-
-    f.save(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT.htc")
+    print(f.input_files())
+#     f.save(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT_power_curve.htc")
+#
+#     f = HTCFile(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT.htc", "../")
+#     f.set_time = 0, 1, .1
+#     print(f.simulate(r"C:\mmpe\HAWC2\bin\HAWC2_12.8\hawc2mb.exe"))
+#
+#     f.save(r"C:\mmpe\HAWC2\models\DTU10MWRef6.0\htc\DTU_10MW_RWT.htc")
