@@ -1,11 +1,5 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-from builtins import str
 import glob
-from io import open
 import json
 import os
 import re
@@ -13,7 +7,6 @@ import sys
 from threading import Thread
 import time
 
-from future import standard_library
 from wetb.hawc2 import log_file
 from wetb.hawc2.htc_file import HTCFile, fmt_path
 from wetb.hawc2.log_file import LogFile
@@ -22,7 +15,6 @@ import stat
 import shutil
 
 
-standard_library.install_aliases()
 
 QUEUED = "queued"  # until start
 PREPARING = "Copy to host"  # during prepare simulation
@@ -72,8 +64,15 @@ class Simulation(object):
     is_done = False
     status = QUEUED
 
-    def __init__(self, modelpath, htcfilename, hawc2exe="HAWC2MB.exe", copy_turbulence=True):
-        self.modelpath = os.path.abspath(modelpath) + "/"
+    def __init__(self, modelpath, htcfile, hawc2exe="HAWC2MB.exe", copy_turbulence=True):
+        if isinstance(htcfile, HTCFile):
+            htcfilename = htcfile.filename
+        else:
+            htcfilename = htcfile
+
+        self.modelpath = os.path.abspath(modelpath).replace("\\", "/")
+        if self.modelpath[-1] != '/':
+            self.modelpath += "/"
         if os.path.isabs(htcfilename):
             htcfilename = os.path.relpath(htcfilename, modelpath)
         if htcfilename.startswith("input/"):
@@ -101,7 +100,10 @@ class Simulation(object):
         self.folder = os.path.dirname(htcfilename)
 
         self.filename = os.path.basename(htcfilename)
-        self.htcFile = HTCFile(os.path.join(self.exepath, htcfilename), self.exepath)
+        if isinstance(htcfile, HTCFile):
+            self.htcFile = htcfile
+        else:
+            self.htcFile = HTCFile(os.path.join(self.exepath, htcfilename), self.exepath)
         self.time_stop = self.htcFile.simulation.time_stop[0]
         self.hawc2exe = hawc2exe
         self.copy_turbulence = copy_turbulence
@@ -127,9 +129,6 @@ class Simulation(object):
         self.logFile.clear()
         self.last_status = self.status
         self.errors = []
-        self.non_blocking_simulation_thread = Thread(
-            target=lambda: self.simulate_distributed(raise_simulation_errors=False))
-        self.updateSimStatusThread = UpdateSimStatusThread(self)
         from wetb.hawc2.simulation_resources import LocalSimulationHost
         self.host = LocalSimulationHost(self)
         self.stdout = ""
@@ -139,8 +138,11 @@ class Simulation(object):
         """Start non blocking distributed simulation"""
         self.is_simulating = True
         if update_interval > 0:
+            self.updateSimStatusThread = UpdateSimStatusThread(self)
             self.updateSimStatusThread.interval = update_interval
             self.updateSimStatusThread.start()
+        self.non_blocking_simulation_thread = Thread(
+            target=lambda: self.simulate_distributed(raise_simulation_errors=False))
         self.non_blocking_simulation_thread.start()
 
     def wait(self):
@@ -245,7 +247,7 @@ class Simulation(object):
                 self.errors = (list(set([l for l in self.host.stdout.split(
                     "\n") if 'error' in l.lower() and not 'rms error' in l])))
             self.status = ERROR
-        if 'HAWC2MB version:' not in self.host.stdout and 'Build information for HAWC2MB.exe (GIT)' not in self.host.stdout:
+        if 'HAWC2MB version:' not in self.host.stdout and 'Build information for HAWC2MB' not in self.host.stdout:
             self.errors.append(self.host.stdout)
             self.status = ERROR
 
@@ -334,32 +336,32 @@ class Simulation(object):
 
     def simulate_distributed(self, raise_simulation_errors=True):
         try:
-            tmpdirname = tempfile.TemporaryDirectory(prefix="h2launcher_%s_" % os.path.basename(self.filename)).name
-            self.tmp_modelpath = tmpdirname + "/"
-            self.tmp_exepath = os.path.join(self.tmp_modelpath, os.path.relpath(self.exepath, self.modelpath)) + "/"
-            self.prepare_simulation()
-            try:
-                self.simulate()
-            except Warning as e:
-                print("simulation failed", str(self))
-                print("Trying to finish")
-                raise
-            finally:
+            with tempfile.TemporaryDirectory(prefix="h2launcher_%s_" % os.path.basename(self.filename)) as tmpdirname:
+                self.tmp_modelpath = tmpdirname + "/"
+                self.tmp_exepath = os.path.join(self.tmp_modelpath, os.path.relpath(self.exepath, self.modelpath)) + "/"
+                self.prepare_simulation()
                 try:
-                    if self.status != ABORTED:
-                        self.finish_simulation()
-                except Exception:
-                    print("finish_simulation failed", str(self))
+                    self.simulate()
+                except Warning as e:
+                    print("simulation failed", str(self))
+                    print("Trying to finish")
                     raise
                 finally:
-                    def remove_readonly(fn, path, excinfo):
-                        try:
-                            os.chmod(path, stat.S_IWRITE)
-                            fn(path)
-                        except Exception as exc:
-                            print("Skipped:", path, "because:\n", exc)
-
-                    shutil.rmtree(tmpdirname, onerror=remove_readonly)
+                    try:
+                        if self.status != ABORTED:
+                            self.finish_simulation()
+                    except Exception:
+                        print("finish_simulation failed", str(self))
+                        raise
+#                     finally:
+#                         def remove_readonly(fn, path, excinfo):
+#                             try:
+#                                 os.chmod(path, stat.S_IWRITE)
+#                                 fn(path)
+#                             except Exception as exc:
+#                                 print("Skipped:", path, "because:\n", exc)
+#
+#                         shutil.rmtree(tmpdirname, onerror=remove_readonly)
 
         except Exception as e:
             self.status = ERROR
@@ -373,7 +375,8 @@ class Simulation(object):
         def confirm_add_additional_file(folder, file):
             if os.path.isfile(os.path.join(self.modelpath, folder, file)):
                 filename = fmt_path(os.path.join(folder, file))
-                if self.get_confirmation("File missing", "'%s' seems to be missing in the temporary working directory. \n\nDo you want to add it to additional_files.txt" % filename):
+                if self.get_confirmation(
+                        "File missing", "'%s' seems to be missing in the temporary working directory. \n\nDo you want to add it to additional_files.txt" % filename):
                     self.add_additional_input_file(filename)
                     self.show_message(
                         "'%s' is now added to additional_files.txt.\n\nPlease restart the simulation" % filename)
