@@ -3,15 +3,6 @@ Created on 17/07/2014
 
 @author: MMPE
 '''
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-from __future__ import absolute_import
-from io import open
-from builtins import str
-from builtins import zip
-from future import standard_library
-standard_library.install_aliases()
 import os
 import unittest
 
