@@ -4,20 +4,8 @@ Created on Thu Sep 18 13:00:25 2014
 
 @author: dave
 """
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-from __future__ import absolute_import
-from builtins import dict
-from builtins import str
-from builtins import range
-from future import standard_library
-standard_library.install_aliases()
-
 import os
-import socket
 from argparse import ArgumentParser
-from sys import platform
 
 import numpy as np
 import pandas as pd
@@ -33,18 +21,18 @@ plt.rc('font', family='serif')
 plt.rc('xtick', labelsize=10)
 plt.rc('ytick', labelsize=10)
 plt.rc('axes', labelsize=12)
-# on Gorm tex printing doesn't work
-if socket.gethostname()[:2] in ['g-', 'je', 'j-']:
-    RUNMETHOD = 'pbs'
-else:
-    plt.rc('text', usetex=True)
-    # set runmethod based on the platform host
-    if platform in ["linux", "linux2", "darwin"]:
-        RUNMETHOD = 'linux-script'
-    elif platform == "win32":
-        RUNMETHOD = 'windows-script'
-    else:
-        RUNMETHOD = 'none'
+# plt.rc('text', usetex=True)
+
+# import socket
+# from sys import platform
+# set runmethod based on the platform host
+# if platform in ["linux", "linux2", "darwin"]:
+#     RUNMETHOD = 'linux-script'
+# elif platform == "win32":
+#     RUNMETHOD = 'windows-script'
+# else:
+#     RUNMETHOD = 'none'
+RUNMETHOD = 'none'
 plt.rc('legend', fontsize=11)
 plt.rc('legend', numpoints=1)
 plt.rc('legend', borderaxespad=0)
@@ -268,7 +256,8 @@ def launch_dlcs_excel(sim_id, silent=False, verbose=False, pbs_turb=False,
                       walltime='04:00:00', postpro_node=False, compress=False,
                       dlcs_dir='htc/DLCs', postpro_node_zipchunks=True,
                       wine_arch='win32', wine_prefix='.wine32', ppn=17,
-                      m=[3,4,6,8,9,10,12], prelude='', linux=False):
+                      m=[3,4,6,8,9,10,12], prelude='', linux=False,
+                      update_model_data=False):
     """
     Launch load cases defined in Excel files
     """
@@ -277,7 +266,6 @@ def launch_dlcs_excel(sim_id, silent=False, verbose=False, pbs_turb=False,
     iter_dict['[empty]'] = [False]
 
     if postpro_node or postpro_node_zipchunks:
-#        pyenv = 'py36-wetb'
         pyenv = 'py36-wetb'
     else:
         pyenv = None
@@ -354,7 +342,8 @@ def launch_dlcs_excel(sim_id, silent=False, verbose=False, pbs_turb=False,
                                m=[3,4,6,8,9,10,12], postpro_node=postpro_node,
                                exechunks=None, exesingle=None, prelude=prelude,
                                postpro_node_zipchunks=postpro_node_zipchunks,
-                               wine_arch=wine_arch, wine_prefix=wine_prefix)
+                               wine_arch=wine_arch, wine_prefix=wine_prefix,
+                               update_model_data=update_model_data)
 
     if pbs_turb:
         # to avoid confusing HAWC2 simulations and Mann64 generator PBS files,
@@ -377,7 +366,7 @@ def launch_dlcs_excel(sim_id, silent=False, verbose=False, pbs_turb=False,
                               prelude=prelude, ppn_pbs=20)
 
     df = sim.Cases(cases).cases2df()
-    df.to_excel(os.path.join(POST_DIR, sim_id + '.xls'))
+    df.to_excel(os.path.join(POST_DIR, sim_id + '.xlsx'))
 
 
 def post_launch(sim_id, statistics=True, rem_failed=True, check_logs=True,
@@ -541,7 +530,8 @@ def postpro_node_merge(tqdm=False, zipchunks=False):
     with open(fcsv.replace('.csv', '2.csv'), 'w') as f1:
         with open(fcsv) as f2:
             for line in f2.readlines():
-                if len(line.split(';'))==96:
+                # older versions had 95, columns, newer 103
+                if len(line.split(';'))==96 or len(line.split(';'))==104:
                     line = line.replace(';0.00000000000;nan;-0.0000;',
                                         '0.00000000000;nan;-0.0000;')
                 f1.write(line)
@@ -820,6 +810,14 @@ if __name__ == '__main__':
         prepare_failed(zipchunks=opt.zipchunks, compress=opt.compress,
                        wine_arch=opt.wine_arch, wine_prefix=opt.wine_prefix)
     if opt.dlcplot:
+
+        # simply plot all channels
+        # fname = os.path.join(POST_DIR, '%s_unique-channel-names.csv' % sim_id)
+        # df = pd.read_csv(fname, header=0, names=['c1', 'c2'])
+        # plot_chans = {}
+        # for i, k in enumerate(df['c2'].values.tolist()):
+        #     plot_chans['i=%i' % i] = [k]
+
         plot_chans = {}
         plot_chans['$B1_{flap}$'] = ['setbeta-bladenr-1-flapnr-1']
         plot_chans['$B2_{flap}$'] = ['setbeta-bladenr-2-flapnr-1']
@@ -842,14 +840,12 @@ if __name__ == '__main__':
         plot_chans['$B123_{pitch}$'] = chans
 
         plot_chans['RPM'] = ['bearing-shaft_rot-angle_speed-rpm']
-        plot_chans['$P_e$'] = ['DLL-2-inpvec-2']
+        plot_chans['$P_e$'] = ['DLL-generator_servo-inpvec-2']
         plot_chans['$P_{mech}$'] = ['stats-shaft-power']
         plot_chans['$B3 U_y$'] = ['global-blade3-elem-018-zrel-1.00-State pos-y']
         plot_chans['$M_x T_B$'] = ['tower-tower-node-001-momentvec-x']
         plot_chans['$M_y T_B$'] = ['tower-tower-node-001-momentvec-y']
         plot_chans['$M_z T_B$'] = ['tower-tower-node-001-momentvec-z']
-        plot_chans['TC blade to tower'] = ['DLL-5-inpvec-2']
-        plot_chans['TC tower to blade'] = ['DLL-5-inpvec-3']
         plot_chans['$M_z T_T$'] = ['tower-tower-node-008-momentvec-z']
         plot_chans['$M_y Shaft_{MB}$'] = ['shaft-shaft-node-004-momentvec-y']
         plot_chans['$M_x Shaft_{MB}$'] = ['shaft-shaft-node-004-momentvec-x']
