@@ -4,19 +4,6 @@ Created on Mon Nov  2 15:23:15 2015
 
 @author: dave
 """
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import absolute_import
-from builtins import range
-from builtins import zip
-from builtins import dict
-from builtins import str
-from builtins import int
-from future import standard_library
-standard_library.install_aliases()
-from builtins import object
-
 import os
 from copy import copy
 
