@@ -6,22 +6,9 @@ Library for general stuff
 
 @author: dave
 """
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
-from __future__ import absolute_import
-from builtins import range
-from builtins import dict
-from builtins import int
-from io import open
-from builtins import str
-from future import standard_library
-standard_library.install_aliases()
-from builtins import object
 
 import os
-import sys
-import shutil
+import io
 import unittest
 import pickle
 import re
@@ -76,6 +63,7 @@ def path_split_dirs(path):
         dirs.pop(0)
     return dirs
 
+
 def path_sanitize(path, allowdd=False, allowabs=False):
     """Raises a ValueError if not considered safe. A leading ../ is allowed
     when allowdd=True.
@@ -120,6 +108,7 @@ def path_sanitize(path, allowdd=False, allowabs=False):
             msg = 'No leading/trailing . or - allowed.'
             raise ValueError('Invalid or unsafe path: "%s". %s' % (path, msg))
 
+
 def sanitize_wine_prefix(wine_prefix):
     """special case to sanitize
     """
@@ -138,13 +127,6 @@ def sanitize_wine_prefix(wine_prefix):
         raise ValueError('Invalid wine_prefix value: %s' % wine_prefix)
     return os.path.join('$HOME', wine_prefix).replace("\\", "/")
 
-def print_both(f, text, end='\n'):
-    """
-    Print both to a file and the console
-    """
-    print(text)
-    if isinstance(f, file):
-        f.write(text + end)
 
 def unique(s):
     """
@@ -218,6 +200,7 @@ def unique(s):
             u.append(x)
     return u
 
+
 def CoeffDeter(obs, model):
     """
     Coefficient of determination
@@ -269,6 +252,7 @@ def calc_sample_rate(time, rel_error=1e-4):
 #        raise AssertionError
     return 1/deltas.mean()
 
+
 def findIntersection(fun1, fun2, x0):
     """
     Find Intersection points of two functions
@@ -298,6 +282,7 @@ def findIntersection(fun1, fun2, x0):
     """
     return sp.optimize.fsolve(lambda x : fun1(x) - fun2(x), x0)
 
+
 # TODO: replace this with some of the pyrain functions
 def find0(array, xi=0, yi=1, verbose=False, zerovalue=0.0):
     """
@@ -410,6 +395,7 @@ def find0(array, xi=0, yi=1, verbose=False, zerovalue=0.0):
 
     return y0, y0i
 
+
 def remove_items(list, value):
     """Remove items from list
     The given list wil be returned withouth the items equal to value.
@@ -429,6 +415,7 @@ def remove_items(list, value):
 
     return list
 
+
 class DictDB(object):
     """
     A dictionary based database class
@@ -536,6 +523,7 @@ class DictDB(object):
             if alltrue:
                 self.dict_sel[row] = self.dict_db[row]
 
+
 class DictDiff(object):
     """
     Calculate the difference between two dictionaries as:
@@ -578,6 +566,7 @@ class DictDiff(object):
         t=set(o for o in self.intersect if self.past_d[o] == self.current_d[o])
         return t
 
+
 def fit_exp(time, data, checkplot=True, method='linear', func=None, C0=0.0):
     """
     Note that all values in data have to be possitive for this method to work!
@@ -624,6 +613,7 @@ def fit_exp(time, data, checkplot=True, method='linear', func=None, C0=0.0):
 
     return fit, A, K, C
 
+
 def curve_fit_exp(time, data, checkplot=True, weights=None):
     """
     This code is based on a StackOverflow question/answer:
@@ -682,70 +672,47 @@ def curve_fit_exp(time, data, checkplot=True, weights=None):
 
     return
 
-def convert_to_utf8(filename):
-    # gather the encodings you think that the file may be
-    # encoded inside a tuple
-    encodings = ('windows-1253', 'iso-8859-7', 'macgreek')
 
-    # try to open the file and exit if some IOError occurs
-    try:
-        f = open(filename, 'r').read()
-    except Exception:
-        sys.exit(1)
+def readlines_try_encodings(fname):
+    """Read text file in binary and try to encode with a few common encodings.
+    Return the first succesful attempt.
+
+    Parameters
+    ----------
+    fname : str
+        Path to file to be read.
+
+    Returns
+    -------
+    lines : list of str
+        Returns same as open(fname).readlines().
+    """
+
+    # some potentially common encoding formats
+    encodings = ('utf-8', 'cp1252', 'iso-8859-1', 'latin-1', 'cp1250',
+                 'cp1251', 'cp1253', 'iso-8859-2', 'iso-8859-7', 'macgreek')
+
+    # open the file and read entire object in as bytes, we do this to avoid
+    # re-opening and reading the file for each encoding we try
+    with open(fname, 'rb') as fid:
+        fbytes = fid.read()
 
-    # now start iterating in our encodings tuple and try to
-    # decode the file
     for enc in encodings:
+        # convert to a file object
+        fid = io.BytesIO(fbytes)
         try:
-            # try to decode the file with the first encoding
-            # from the tuple.
-            # if it succeeds then it will reach break, so we
-            # will be out of the loop (something we want on
-            # success).
-            # the data variable will hold our decoded text
-            data = f.decode(enc)
+            # we want to mimic the standard readlines behaviour
+            text_wrapper = io.TextIOWrapper(fid, encoding=enc)
+            lines = text_wrapper.readlines()
+        except UnicodeDecodeError:
+            print('encoding with', enc, 'does not work for:', fname)
+            print('unicode error with %s , trying different encoding' % enc)
+            pass
+        else:
+            # print('opening the file with encoding:  %s ' % enc)
             break
-        except Exception:
-            # if the first encoding fail, then with the continue
-            # keyword will start again with the second encoding
-            # from the tuple an so on.... until it succeeds.
-            # if for some reason it reaches the last encoding of
-            # our tuple without success, then exit the program.
-            if enc == encodings[-1]:
-                sys.exit(1)
-            continue
+    return lines
 
-    # now get the absolute path of our filename and append .bak
-    # to the end of it (for our backup file)
-    fpath = os.path.abspath(filename)
-    newfilename = fpath + '.bak'
-    # and make our backup file with shutil
-    shutil.copy(filename, newfilename)
-
-    # and at last convert it to utf-8
-    f = open(filename, 'w')
-    try:
-        f.write(data.encode('utf-8'))
-    except Exception(e):
-        print(e)
-    finally:
-        f.close()
-
-def to_lower_case(proot):
-    """
-    Rename all the files in the subfolders of proot to lower case, and
-    also the subfolder name when it the folder name starts with DLC
-    """
-    # find all dlc defintions in the subfolders
-    for root, dirs, files in os.walk(proot):
-        for fname in files:
-            orig = os.path.join(root, fname)
-            rename = os.path.join(root, fname.lower())
-            os.rename(orig, rename)
-        base = root.split(os.path.sep)[-1]
-        if base[:3] == 'DLC':
-            new = root.replace(base, base.lower())
-            os.rename(root, new)
 
 def read_excel_files(proot, fext='xlsx', pignore=None, sheet=0,
                      pinclude=None, silent=False):
@@ -812,21 +779,6 @@ def read_excel_files(proot, fext='xlsx', pignore=None, sheet=0,
 
     return df_list
 
-def convert_xlsx2csv(fpath, sheet='Sheet1', fext='xlsx'):
-    """
-    Convert xlsx load case definitions to csv so we can track them with git
-    """
-
-    for root, dirs, files in os.walk(fpath):
-        for file_name in files:
-            if not file_name.split('.')[-1] == fext:
-                continue
-            fxlsx = os.path.join(root, file_name)
-            print(fxlsx)
-            xl = pd.ExcelFile(fxlsx)
-            df = xl.parse(sheet)
-            fcsv = fxlsx.replace(fext, 'csv')
-            df.to_csv(fcsv, sep=';')
 
 def check_df_dict(df_dict):
     """
