@@ -4,20 +4,6 @@ Created on Mon Aug  8 10:22:49 2016
 
 @author: dave
 """
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
-from __future__ import absolute_import
-from builtins import dict
-from io import open
-from builtins import zip
-from builtins import range
-from builtins import str
-from builtins import int
-from future import standard_library
-standard_library.install_aliases()
-from builtins import object
-
 # standard python library
 import os
 from os.path import join as pjoin
@@ -725,6 +711,9 @@ def merge_from_tarfiles(df_fname, path, pattern, tarmode='r:xz', tqdm=False,
         def tqdm(itereable):
             return itereable
 
+    if len(glob.glob(os.path.join(path, pattern))) < 1:
+        raise RuntimeError('No files found to merge')
+
     for tar_fname in tqdm(glob.glob(os.path.join(path, pattern))):
         if verbose:
             print(tar_fname)
