@@ -3,16 +3,8 @@ Created on 10/03/2014
 
 @author: MMPE
 '''
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from builtins import range
-from builtins import str
-from future import standard_library
 import glob
 import re
-standard_library.install_aliases()
 
 import os
 
