@@ -8,8 +8,8 @@ import wetb
 import inspect
 from urllib.request import urlretrieve
 
-wetb_rep_path = os.path.abspath(os.path.dirname(wetb.__file__) + "/../") + "/"
-local_TestFiles_path = wetb_rep_path + "TestFiles/"                                   
+wetb_rep_path = os.path.abspath(os.path.dirname(wetb.__file__) + "/../").replace("\\", "/") + "/"
+local_TestFiles_path = wetb_rep_path + "TestFiles/"
 remote_TestFiles_url = "https://gitlab.windenergy.dtu.dk/toolbox/TestFiles/raw/master/"
 
 
@@ -19,19 +19,17 @@ def _absolute_filename(filename):
         caller_module_path = os.path.dirname(inspect.stack()[index][1])
         tfp = caller_module_path + "/test_files/"
         filename = tfp + filename
-    return filename
+    return os.path.abspath(filename).replace("\\", "/")
+
 
 def get_test_file(filename):
-    filename = _absolute_filename(filename) 
+    filename = _absolute_filename(filename)
     if not os.path.exists(filename):
-        rel_path = os.path.relpath(filename, wetb_rep_path).replace("\\","/")
+        rel_path = os.path.relpath(filename, wetb_rep_path).replace("\\", "/")
         filename = local_TestFiles_path + rel_path
         if not os.path.exists(filename):
             urlretrieve(remote_TestFiles_url + rel_path, filename)
     return filename
-        
-        
-
 
 
 def move2test_files(filename):
@@ -42,8 +40,3 @@ def move2test_files(filename):
     if not os.path.exists(folder):
         os.makedirs(folder)
     os.rename(filename, dst_filename)
-    
-    
-    
-    
-    
\ No newline at end of file
